@@ -5,9 +5,11 @@ gen.trun <-function(par = c(0),
                      ...)
  {
   type <- match.arg(type)
-  fname <- family
-  if (mode(family) != "character" && mode(family) != "name")
-  fname <- as.character(substitute(family))
+   fam  <- as.gamlss.family(family) #ds Monday, March 10, 2008 at 10:07
+  fname <- fam$family[[1]] 
+ # fname <- family
+ # if (mode(family) != "character" && mode(family) != "name")
+ # fname <- as.character(substitute(family))
    dfun <- paste(paste("d",fname,sep=""), name, sep="")
    pfun <- paste(paste("p",fname,sep=""), name, sep="")
    qfun <- paste(paste("q",fname,sep=""), name, sep="")
@@ -27,7 +29,7 @@ gen.trun <-function(par = c(0),
    eval(dummy <- trun.r(par, family = fname, type = type, ...))
    eval(call("<-",as.name(rfun),dummy), envir=parent.frame(n = 1))
    # generate the fitting distribution
-   eval(dummy <- trun(par, family = fname, type = type, name=name, local=FALSE, ...))
+   eval(dummy <- trun(par, family = family, type = type, name=name, local=FALSE, ...))
    eval(call("<-",as.name(fun),dummy), envir=parent.frame(n = 1))
   cat("A truncated family of distributions from",  fname, "has been generated \n", 
   "and saved under the names: ", "\n",paste(alldislist,sep=","),"\n")#
